# Changelog

The changelog is currently hosted on [the GitHub Releases page](https://github.com/agilgur5/django-serializable-model/releases).<br>
It is currently mostly a summary and list of commits made before any tag.
The commits in this library mostly follow a convention and tend to be quite detailed.

This project adheres to [Semantic Versioning](http://semver.org/).
